:py:mod:`simplemseed.mseed3details`
===================================

.. py:module:: simplemseed.mseed3details

.. autodoc2-docstring:: simplemseed.mseed3details
   :allowtitles:

Module Contents
---------------

Functions
~~~~~~~~~

.. list-table::
   :class: autosummary longtable
   :align: left

   * - :py:obj:`do_details <simplemseed.mseed3details.do_details>`
     - .. autodoc2-docstring:: simplemseed.mseed3details.do_details
          :summary:
   * - :py:obj:`do_get_eh <simplemseed.mseed3details.do_get_eh>`
     - .. autodoc2-docstring:: simplemseed.mseed3details.do_get_eh
          :summary:
   * - :py:obj:`do_parseargs <simplemseed.mseed3details.do_parseargs>`
     - .. autodoc2-docstring:: simplemseed.mseed3details.do_parseargs
          :summary:
   * - :py:obj:`do_set_eh <simplemseed.mseed3details.do_set_eh>`
     - .. autodoc2-docstring:: simplemseed.mseed3details.do_set_eh
          :summary:
   * - :py:obj:`main <simplemseed.mseed3details.main>`
     - .. autodoc2-docstring:: simplemseed.mseed3details.main
          :summary:

API
~~~

.. py:function:: do_details()
   :canonical: simplemseed.mseed3details.do_details

   .. autodoc2-docstring:: simplemseed.mseed3details.do_details

.. py:function:: do_get_eh(getptr, ms3files, matchsid=None, getall=False, outfile=None, verbose=False)
   :canonical: simplemseed.mseed3details.do_get_eh

   .. autodoc2-docstring:: simplemseed.mseed3details.do_get_eh

.. py:function:: do_parseargs()
   :canonical: simplemseed.mseed3details.do_parseargs

   .. autodoc2-docstring:: simplemseed.mseed3details.do_parseargs

.. py:function:: do_set_eh(setptr, setval, ms3files, matchsid=None, setall=False, verbose=False)
   :canonical: simplemseed.mseed3details.do_set_eh

   .. autodoc2-docstring:: simplemseed.mseed3details.do_set_eh

.. py:function:: main()
   :canonical: simplemseed.mseed3details.main

   .. autodoc2-docstring:: simplemseed.mseed3details.main
